#+LATEX_CLASS: article
#+LATEX_CLASS_OPTIONS: [a4paper]
#+OPTIONS: toc:nil ^:{}
#+STARTUP: hideblocks
#+TITLE: Reading and writing tables using Python
#+AUTHOR: Martin Schöön

* Input

#+tblname: input_table
| boat speed | 11 | knots |
| apparent wind angle | 21 | degrees |
| true wind speed | 14 | knots |

* Output

#+begin_src python -n :results output :var indata=input_table
from scipy import optimize
import numpy as np

def f1(x):
    '''First equation of equation system.'''
    return x[0] * np.sin((awa + x[1]) / 57.296) \
           - bs * np.sin(x[1] / 57.296) - tws

def f2(x):
    '''Second equation of equation system.'''
    return x[0] * np.cos((awa + x[1]) / 57.296) \
           - bs * np.cos(x[1] / 57.296)

def vf(x):
    '''Preparing equation system for fsolve.'''
    return [f1(x), f2(x)]


# Indata read from input_table in beginning of document.
awa = indata[1][1] # Apparent wind angle.
bs = indata[0][1]  # Boat speed.
tws = indata[2][1] # True wind speed.

# fsolve uses Powell's hybrid method to find a local zero.
# An initial guess, x0, is provided.
xx = optimize.fsolve(vf, x0 = [24., 52.])

# Return Apparent wind speed, b, VMG and tacking angle.
print '#+tblname: results'
print '| variable | value | unit |'
print '|-'
print '| AWS | %3.1f | knots |' % xx[0]
print '| b | %3.1f | degrees |' % xx[1]
print '| VMG | %2.1f | knots |' % (11. * np.sin(xx[1] / 57.296))
print '| tack | %3.1f | degrees |' % (2. * (90. - xx[1]))
#+end_src

#+RESULTS:
: #+tblname: results
: | variable | value | unit |
: |-
: | AWS | 23.7 | knots |
: | b | 52.6 | degrees |
: | VMG | 8.7 | knots |
: | tack | 74.7 | degrees |

